@@ -71,28 +71,65 @@ EOM
 }
 
 
+## BUG 58729 - LRO
+## Docker must be installed at install step and not and the init step, because registry yum is
+## available by container MDT bootstrap httpd
+## Update installation to be consistent with Kubespray Docker installation
 install_docker ()
 {
-    yum --disablerepo=* --enablerepo=$REPO_NAME -y install --setopt=obsoletes=0 docker-ce docker-ce-selinux
+    # Install Docker version in REPO_NAME
+    yum --disablerepo=* --enablerepo=$REPO_NAME -y install --setopt=obsoletes=0 docker-ce
     usermod -aG docker root
 
-    # Folowing configuration work with docker 1.12, not 1.9
+    # Service file
     mkdir -p /etc/systemd/system/docker.service.d
-    cat << EOF > /etc/systemd/system/docker.service.d/docker.conf
+    cat << EOF > /etc/systemd/system/docker.service
+[Unit]
+Description=Docker Application Container Engine
+Documentation=http://docs.docker.com
+After=network.target docker-storage-setup.service
+Wants=docker-storage-setup.service
+
 [Service]
-EnvironmentFile=-/etc/sysconfig/docker
-ExecStart=
-ExecStart=/usr/bin/dockerd \$OPTIONS
+Type=notify
+ExecReload=/bin/kill -s HUP $MAINPID
+Delegate=yes
+KillMode=process
+ExecStart=/usr/bin/dockerd \\
+          \$DOCKER_OPTS \\
+          \$DOCKER_STORAGE_OPTIONS \\
+          \$DOCKER_NETWORK_OPTIONS \\
+          \$DOCKER_DNS_OPTIONS \\
+          \$INSECURE_REGISTRY
+LimitNOFILE=1048576
+LimitNPROC=1048576
+LimitCORE=infinity
+TimeoutStartSec=1min
+# restart the docker process if it exits prematurely
+Restart=on-failure
+StartLimitBurst=3
+StartLimitInterval=60s
+
+[Install]
+WantedBy=multi-user.target
+
 EOF
 
-    ## WORKAROUND docker 1.9 : https://github.com/docker/docker/issues/17653 --exec-opt native.cgroupdriver=cgroupfs
+    ## Configuration file
+    cat << EOF > /etc/systemd/system/docker.service.d/docker-options.conf
+[Service]
+Environment="DOCKER_OPTS=--log-opt max-size=50m --log-opt max-file=5"
 
-    DOCKER_OPTS='OPTIONS=" -H unix:///var/run/docker.sock  --exec-opt native.cgroupdriver=cgroupfs'
-    if [ $DOCKER_OVERLAY_FS == "true" ]; then
-        DOCKER_OPTS+=' --storage-driver=overlay'
-    fi
-    DOCKER_OPTS+='"'
-    echo $DOCKER_OPTS > /etc/sysconfig/docker
+EOF
+
+    # Install Docker compose
+    cp /opt/mfvp/deploypattern/ansible/files/docker-compose /usr/bin/docker-compose
+    chmod 0744 /usr/bin/docker-compose
+
+    ## BUG 61208 - LRO
+    ## Backup Docker configuration files, which are deleted by reset kube cluster
+    cp /etc/systemd/system/docker.service.d/docker-options.conf /etc/systemd/system/docker.service.d/docker-options.conf_bk
+    cp /etc/systemd/system/docker.service /etc/systemd/system/docker.service_bk
 
     systemctl daemon-reload
     systemctl enable docker
@@ -150,7 +187,7 @@ create_local_repo
 
 
 echo -e "\n***** Installing $RPM_NAME package ..."
-find $REPO_DIR -name "$RPM_NAME*.rpm" -exec yum --enablerepo=$REPO_NAME -y install {} \;
+find $REPO_DIR -name "$RPM_NAME*.rpm" -exec yum --disablerepo=* --enablerepo=$REPO_NAME -y install {} \;
 
 echo -e "\n***** Installing helm package ..."
 tar -zxf $RESOURCES_DIR/$HELM && mv ./linux-amd64/helm /usr/bin/helm
@@ -159,6 +196,12 @@ rm -rf RESOURCES_DIR/linux-amd64
 echo -e "\n***** Installing docker ..."
 install_docker
 
+echo -e "\n***** Configure Ansible ..."
+mkdir -p /etc/ansible/
+cp /opt/mfvp/deploypattern/ansible/files/ansible.conf  /etc/ansible/ansible.cfg
+touch /var/log/ansible.log
+chmod 0666 /var/log/ansible.log
+
 echo -e "\n***** create path for static files ..."
 mkdir -p /var/www/ericsson/static/  && chown daemon:daemon /var/www/ericsson/static/
 
