@@ -1,4 +1,6 @@
-#!/bin/sh -eo pipefail
+#!/bin/sh
+set -eo pipefail
+
 #Generate MD formatted tags from roles and cluster yaml files
 printf "|%25s |%9s\n" "Tag name" "Used for"
 echo "|--------------------------|---------"
