@@ -26,6 +26,8 @@ import logging
 import logging.handlers
 import subprocess
 import os
+import shutil
+import tarfile
 from ericsson.deploypattern.tools.mdtcli import exec_cmd_shell
 
 from ericsson.deploypattern.lib import errors
@@ -35,7 +37,6 @@ from ericsson.deploypattern.lib.config import Config
 from ericsson.deploypattern.lib.inventory import inventory_command
 from ericsson.deploypattern.plugins.deployplugins import load_plugin
 from ericsson.deploypattern.plugins.pattern import pattern
-from ericsson.deploypattern.tools import labels
 from ericsson.deploypattern.tools.dfninit import mgnt_server_init, check_init
 from ericsson.deploypattern.tools.yum import load_yum_repo
 from ericsson.deploypattern.tools.apt import load_deb_repo
@@ -45,29 +46,46 @@ from ericsson.deploypattern.tools import bundle
 from ericsson.deploypattern.tools import mdtcli
 from ericsson.deploypattern.version import __version__
 
-# create logger
-logger = logging.getLogger()
-logger.setLevel(logging.INFO)
+class LoggingLevelFilter(logging.Filter):
 
-# Console Handler
-ch = logging.StreamHandler()
-ch.setLevel(logging.INFO)
-# formatter = logging.Formatter('%(message)s')
-# ch.setFormatter(formatter)
-logger.addHandler(ch)
+    def __init__(self, min_level=logging.NOTSET, max_level=logging.CRITICAL):
+        super(logging.Filter, self).__init__()
+        self.min_level = min_level
+        self.max_level = max_level
+
+    def filter(self, record):
+        return record.levelno \
+            if self.min_level <= record.levelno <= self.max_level \
+            else False
+
+# create logger
+LOGGER = logging.getLogger()
+LOGGER.setLevel(logging.INFO)
+
+# Console Handlerr for stderr
+CH_ERR = logging.StreamHandler(stream=sys.stderr)
+CH_ERR.addFilter(LoggingLevelFilter(min_level=logging.ERROR))
+CH_ERR.setLevel(logging.ERROR)
+# Console Handler for stdout
+CH_OUT = logging.StreamHandler(stream=sys.stdout)
+CH_OUT.addFilter(LoggingLevelFilter(min_level=logging.DEBUG, max_level=logging.WARNING))
+CH_OUT.setLevel(logging.DEBUG)
+
+LOGGER.addHandler(CH_ERR)
+LOGGER.addHandler(CH_OUT)
 
 # File Handler
-formatter = logging.Formatter('%(asctime)s:'
+FORMATTER = logging.Formatter('%(asctime)s:'
                               '%(levelname)s:'
                               '%(filename)s:'
                               '%(funcName)s:'
                               ' %(message)s')
-fh = logging.handlers.RotatingFileHandler(
+F_H = logging.handlers.RotatingFileHandler(
     '/tmp/deploypattern.log', 'a', 1000000, 1)
-# fh = logging.FileHandler('/var/log/deploypattern.log')
-fh.setLevel(logging.INFO)
-fh.setFormatter(formatter)
-logger.addHandler(fh)
+# F_H = logging.FileHandler('/var/log/deploypattern.log')
+F_H.setLevel(logging.INFO)
+F_H.setFormatter(FORMATTER)
+LOGGER.addHandler(F_H)
 
 # For Ansible Log
 # Ansible add FileHandler to root logger
@@ -77,7 +95,7 @@ logger.addHandler(fh)
 for key in logging.Logger.manager.loggerDict.keys():
     if ' | ' in key:
         logging.Logger.manager.loggerDict[key].propagate = False
-        logging.Logger.manager.loggerDict[key].addHandler(fh)
+        logging.Logger.manager.loggerDict[key].addHandler(F_H)
 
 DFN_CONF_FILE = '/etc/deploypattern.conf'
 
@@ -102,8 +120,8 @@ def run_pattern(deploy_pattern):
     tasks_list = deploy_pattern['deployment_tasks']
 
     for task in tasks_list:
-        logger.info("\n:: %s ::", task['name'])
-        logger.info("--------------------------")
+        LOGGER.info("\n:: %s ::", task['name'])
+        LOGGER.info("--------------------------")
 
         # get task type
         __deployment_type = task['type']
@@ -120,15 +138,21 @@ def redirect_to_cli(command):
     :return:
     """
     def handle(parsed_args, unknown_args):
+        """
+        Handle to manage Help
+        :param parsed_args:
+        :param unknown_args:
+        :return handle:
+        """
         if unknown_args.count("-h") != 0 or unknown_args.count("--help") != 0:
-            cmd = 'sudo docker exec mdt-cli mdt {} {}'.format(
+            cmd = 'sudo docker exec --user root mdt-cli mdt {} {}'.format(
                 command, ' '.join(unknown_args))
             returncode, stdout, stderr = exec_cmd_shell(cmd)
             if returncode == 0:
-                logger.info(stdout)
+                LOGGER.info(stdout)
                 exit(0)
             else:
-                logger.error("stderr : " + stderr)
+                LOGGER.error("stderr : %s", stderr)
                 exit(1)
             try:
                 unknown_args.remove("-h")
@@ -194,10 +218,24 @@ For allinone installation the local disk will be used instead of NFS server
     reset_parser = subparsers.add_parser('reset',
                                          usage='mdt [mdt_options] reset [resource] [command_options]',
                                          help='Reset ressources')
-    # set_parser = subparsers.add_parser('set',
-    #                                   usage='mdt [mdt_options] set [resource] [command_options]',
-    #                                   help='Set resource')
-
+    set_parser = subparsers.add_parser('set',
+                                       usage='mdt [mdt_options] set [resource] [command_options]',
+                                       help='Set ressources')
+    unset_parser = subparsers.add_parser('unset',
+                                         usage='mdt [mdt_options] unset [resource] [command_options]',
+                                         help='Unset ressources')
+    add_val_parser = subparsers.add_parser('add',
+                                           usage='mdt [mdt_options] add [resource] [command_options]',
+                                           help='Add ressources')
+    delete_parser = subparsers.add_parser('delete',
+                                          usage='mdt [mdt_options] delete [resource] [command_options]',
+                                          help='Delete ressources')
+    upgrade_parser = subparsers.add_parser('upgrade',
+                                           usage='mdt [mdt_options] upgrade [resource] [command_options]',
+                                           help='Upgrade ressources')
+    audit_parser = subparsers.add_parser('audit',
+                                         usage='mdt [mdt_options] audit [resource] [command_options]',
+                                         help='Audit ressources')
     # Command deploy
     # -----------------
     deploy_sub_parser = deploy_parser.add_subparsers(dest='cmd_deploy')
@@ -255,10 +293,17 @@ A storage class is defined with 4 parameters:
 
     reset_kubecluster_parser = reset_sub_parser.add_parser('kube-cluster',
                                                            description=('''
-Reset the Kubernetes cluster on all nodes and clean load balancers. The inventory, list of nodes, is given by the mdt-matrix file in the config bundle folder.
+Reset the Kubernetes cluster on all nodes and clean load balancers. 
+The inventory, list of nodes, is given by the mdt-matrix file in the config bundle folder.
                                                 '''),
                                                            formatter_class=argparse.RawDescriptionHelpFormatter,
                                                            usage='mdt [mdt_options] reset kube-cluster')
+    reset_volumes_parser = reset_sub_parser.add_parser('volumes',
+                                                       description=('''
+    Reset all volumes to the state before using the deploy command.
+                                                    '''),
+                                                       formatter_class=argparse.RawDescriptionHelpFormatter,
+                                                       usage='mdt [mdt_options] reset volumes')
 
     # Command get
     # ---------------
@@ -269,19 +314,38 @@ Reset the Kubernetes cluster on all nodes and clean load balancers. The inventor
     get_cfg_parser = get_sub_parser.add_parser('cfg', add_help=False)
     get_cfg_parser.set_defaults(func=redirect_to_cli('get cfg'))
 
+    get_chart_parser = get_sub_parser.add_parser('chart', add_help=False)
+    get_chart_parser.set_defaults(func=redirect_to_cli('get chart'))
+
+    get_context_parser = get_sub_parser.add_parser('context', add_help=False)
+    get_context_parser.set_defaults(func=redirect_to_cli('get context'))
+
     # Command load
     # -------------
     load_sub_parser = load_parser.add_subparsers(dest='cmd_load')
     load_cfg_parser = load_sub_parser.add_parser('cfg', add_help=False)
     load_cfg_parser.set_defaults(func=redirect_to_cli('load cfg'))
 
-    load_mdtchart_parser = load_sub_parser.add_parser('chart',
-                                                      description=('''
-Load Helm charts from HELM_TGZ archive file or HELM_DIR directory path.
-The Helm charts are pushed to the MDT Helm repository: helm_repo.
-                                                '''),
-                                                      formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                      usage='mdt [mdt_options] load chart (-f CHART_TGZ | -d CHART_DIR)')
+    # Command audit
+    # -------------
+    audit_sub_parser = audit_parser.add_subparsers(dest='cmd_audit')
+    audit_kube_cluster_parser = audit_sub_parser.add_parser('kube-cluster',
+                                                            description=('''
+Perform an audit to the nodes that will be used in the kube-cluster.
+You can run the audit for all kube-cluster nodes or for a single node with -n  parameter.
+                                                  '''),
+                                                            formatter_class=argparse.RawDescriptionHelpFormatter,
+                                                            usage='mdt [mdt_options] audit kube-cluster [-n <node>]')
+
+    audit_kube_cluster_parser.add_argument("-n", "--node",
+                                           dest="node",
+                                           default=None,
+                                           help="Node to audit"
+                                           )
+
+    # US 45690 - LRO
+    load_chart_parser = load_sub_parser.add_parser('chart', add_help=False)
+    load_chart_parser.set_defaults(func=redirect_to_cli('load chart'))
 
     load_container_parser = load_sub_parser.add_parser('container',
                                                        description=('''
@@ -318,16 +382,6 @@ The deb are pushed to the local deb repository.
                                  dest="deb_tgz",
                                  help="Path to deb tgz archive to load ")
 
-    # --> mdt load chart -f <tar.gz> | -d <folder>
-    load_mdtchart_exclusive_parser = load_mdtchart_parser.add_mutually_exclusive_group(
-        required=True)
-    load_mdtchart_exclusive_parser.add_argument("-f", "--file",
-                                                dest="chart_tgz",
-                                                help="Path to MDT packages (Helm charts) tgz archive to load ")
-    load_mdtchart_exclusive_parser.add_argument("-d", "--directory",
-                                                dest="chart_dir",
-                                                help="Path to MDT packages (Helm charts) directory to load")
-
     # --> mdt load container [--force] -f <tar.gz> | -d <folder> [-r registry]
     load_container_exclusive_parser = load_container_parser.add_mutually_exclusive_group(
         required=True)
@@ -393,10 +447,52 @@ The deb are pushed to the local deb repository.
     init_parser.add_argument("-c", "--container-3rdparty-path",
                              default=None,
                              dest="thirdparty_path",
-                             help="Path of the 3rd party containers to load, default /opt/mfvp/deploypattern/resources")
+                             help="Path of the 3rd party containers to load, "
+                                  "default /opt/mfvp/deploypattern/resources/filename.tgz")
 
-    # Commands  MDT < 1.5
-    #---------------------
+    # Command set
+    # ----------------
+    set_sub_parser = set_parser.add_subparsers(dest='cmd_set')
+    set_node_parser = set_sub_parser.add_parser('node',
+                                                description='set node on kube-matrix',
+                                                usage='mdt [mdt_options] set node')
+    set_node_parser.add_argument("-n", "--node",
+                                 dest="set_node_value",
+                                 help="node to set")
+    set_node_parser.add_argument("-t", "--type",
+                                 dest="set_node_value_type",
+                                 help="type of node to set")
+
+    # Command unset
+    # ----------------
+    unset_sub_parser = unset_parser.add_subparsers(dest='cmd_unset')
+    unset_node_parser = unset_sub_parser.add_parser('node',
+                                                    description='unset node on kube-matrix',
+                                                    usage='mdt [mdt_options] unset node')
+    unset_node_parser.add_argument("-n", "--node",
+                                   dest="unset_node_value",
+                                   help="node to unset")
+
+    # Command add
+    # ----------------
+    add_sub_parser = add_val_parser.add_subparsers(dest='cmd_add')
+    add_profile_parser = add_sub_parser.add_parser('profile', add_help=False)
+    add_profile_parser.set_defaults(func=redirect_to_cli('add profile'))
+
+    # Command delete
+    # ----------------
+    delete_sub_parser = delete_parser.add_subparsers(dest='cmd_delete')
+    delete_profile_parser = delete_sub_parser.add_parser('profile', add_help=False)
+    delete_profile_parser.set_defaults(func=redirect_to_cli('delete profile'))
+    ## US 45690 - LRO
+    delete_chart_parser = delete_sub_parser.add_parser('chart', add_help=False)
+    delete_chart_parser.set_defaults(func=redirect_to_cli('delete chart'))
+
+    # Command upgrade
+    # ----------------
+    upgrade_sub_parser = upgrade_parser.add_subparsers(dest='cmd_upgrade')
+    upgrade_products_parser = upgrade_sub_parser.add_parser('products', add_help=False)
+    upgrade_products_parser.set_defaults(func=redirect_to_cli('upgrade products'))
 
     # inventory_parser = subparsers.add_parser('inventory',
     #                                          help='Inventory management (MDT <1.5)')
@@ -417,34 +513,12 @@ The deb are pushed to the local deb repository.
     #                               dest="export",
     #                               help="export inventory to ansible format")
 
-    # pattern_parser = subparsers.add_parser(
-    #     'pattern', help='Deploy pattern (MDT <1.5)')
-    # pattern_parser.add_argument("--debug",
-    #                             action="store_true",
-    #                             help="Enable Debug output messages")
-    # pattern_parser.add_argument("-i", "--install",
-    #                             dest="install",
-    #                             help="install pattern")
-    # pattern_parser.add_argument("-l", "--list-config",
-    #                             action="store_true",
-    #                             help="list configuration pattern")
-    # pattern_parser.add_argument("-c", "--config",
-    #                             dest="config",
-    #                             help="set pattern configuration")
-    # pattern_parser.add_argument("-p", "--path",
-    #                             dest="pattern_path",
-    #                             help="set pattern configuration")
-    # pattern_parser.add_argument("-r", "--run",
-    #                             action="store_true",
-    #                             help="run pattern - "
-    #                             "can be combined with -c/--config")
-
     parsed_args, unknown_args = parser.parse_known_args()
 
     if hasattr(parsed_args, 'func'):
         parsed_args.func(parsed_args, unknown_args)
 
-    if len(sys.argv[1:]) == 0:
+    if not sys.argv[1:]:
         parser.print_help()
         parser.exit(2)
 
@@ -457,23 +531,38 @@ def signal_handler(signal, frame):
     sys.exit(0)
 
 
-def __exec_cmd_shell(cmd, error_msg=None):
+def __get_cfg():
     """
+    # US 55043
+    # Because deploy kube cluster is temporary done by front-end
+    # get config bundle from database
+    # and save it to predefined folder /opt/mfvp/deploypattern/bundle
 
-    :param cmd:
-    :param error_msg:
     :return:
     """
-    p = subprocess.Popen(
-        cmd, shell=True, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
-    (stdout, stderr) = p.communicate()
-    logger.debug(":: rc=%s for cmd='%s'" % (p.returncode, cmd))
-    if p.returncode != 0:
-        logger.info(stdout)
-        logger.info(stderr)
-        if error_msg:
-            raise errors.DeployError(error_msg)
-    return(p.returncode, stdout, stderr)
+    try:
+        os.mkdir('/opt/mfvp/deploypattern/bundle', 0755)
+    except Exception as error:
+        pass
+    mdtcli.call_mdt_cli('get', 'cfg', ['-o', '/opt/mfvp/deploypattern/bundle/bundle.tgz'])
+    try:
+        tar = tarfile.open('/opt/mfvp/deploypattern/bundle/bundle.tgz')
+        tar.extractall('/opt/mfvp/deploypattern/bundle/')
+        tar.close()
+    except Exception as msg:
+        LOGGER.error("Get bundle failed: %s", msg.message)
+        return 1
+
+def __clean_cfg():
+    """
+
+    :return:
+    """
+    try:
+        shutil.rmtree('/opt/mfvp/deploypattern/bundle', ignore_errors=True)
+    except Exception as msg:
+        LOGGER.error("Clean bundle failed: %s", msg.message)
+        return 1
 
 def main():
     """ Main """
@@ -488,10 +577,10 @@ def main():
                                       '%(filename)s:'
                                       '%(funcName)s:'
                                       ' %(message)s')
-        ch.setFormatter(formatter)
-        logger.setLevel(logging.DEBUG)
-        ch.setLevel(logging.DEBUG)
-        fh.setLevel(logging.DEBUG)
+        CH_OUT.setFormatter(formatter)
+        LOGGER.setLevel(logging.DEBUG)
+        CH_OUT.setLevel(logging.DEBUG)
+        F_H.setLevel(logging.DEBUG)
 
     # Command mdt init
     # ---------------------
@@ -520,126 +609,118 @@ def main():
                              thirdparty_path=args.thirdparty_path,
                              http_port=args.http_port)
         except Exception as msg:
-            logger.error("Initialization failed: %s" %
-                         msg.message, exc_info=True)
+            LOGGER.error("Initialization failed: %s", msg.message, exc_info=True)
             return 1
 
-    # Command mdt inventory < 1.5
-    # --------------------------
-    if args.cmd == 'inventory':
-        try:
-            inventory_command(args)
-        except Exception as msg:
-            logger.error("Inventory command failed: %s" %
-                         msg.message, exc_info=True)
-            return 1
-        finally:
-            exit(0)
-
     # check if init as been done before going on
     try:
         check_init(config)
     except Exception as msg:
-        logger.error("Init must be done before: %s" % msg.message)
+        LOGGER.error("Init must be done before: %s", msg.message)
         return 1
 
-    # launch deployment pattern
-    if args.cmd == 'pattern':
-        try:
-            pattern(args)
-        except Exception as msg:
-            logger.error("Deploying pattern failed: %s" %
-                         msg.message, exc_info=True)
-            return 1
-
-
-# NEW MDT 1.5
-
     # Command mdt deploy
     # --------------------------
     if args.cmd == 'deploy':
-        if args.cmd_deploy == 'labels':
-            try:
-                labels.set_labels(args.audit)
-            except Exception as msg:
-                logger.error("Deploy labels on nodes failed: %s" % msg.message)
-                return 1
 
         if args.cmd_deploy == 'kube-cluster':
             try:
+                __get_cfg()
                 bundle.Bundle().deploy_kubecluster()
+                __clean_cfg()
+
             except Exception as msg:
-                logger.error("Deploying pattern failed: %s" % msg.message)
+                __clean_cfg()
+                LOGGER.error("Deploying Kube cluster failed: %s", msg.message)
                 return 1
-            # Update mdt_api_products with Docker and Helm parameters after
-            # Kube cluster deployment
 
         if args.cmd_deploy == "helm":
             try:
                 inventory = bundle.Bundle().get_inventory()
                 kube_vars_dict = bundle.Bundle().get_vars_kube_config()
-                # Deploy Helm server (container tiller) only on one master with deployment (replicas=1)
+                # Deploy Helm server (container tiller) only on
+                #  one master with deployment (replicas=1)
                 # Add service to expose Helm server
                 result = ansibleplay.AnsibleRunner().playbook(
                     host_list=inventory,
                     playbooks="deploy_helm",
                     vars=config_lib.get_config_vars_dict(),
                     extra_vars=kube_vars_dict)
-                logger.debug("result : %s" % result)
+                LOGGER.debug("result : %s", result)
                 if result != 0:
                     raise errors.AnsibleError(
                         "Ansible playbook failed : deploy_helm ")
 
             except Exception as msg:
-                logger.error("Install Helm failed: %s" % msg.message)
+                LOGGER.error("Install Helm failed: %s", msg.message)
                 return 1
 
         if args.cmd_deploy == 'products':
-            mdtcli.call_mdt_cli('deploy', 'products', unknown_args)
+            try:
+                mdtcli.call_mdt_cli('deploy', 'products', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Install products failed: %s", msg.message)
+                return 1
 
         if args.cmd_deploy == "volumes":
-            bundle.Bundle().deploy_volumes()
+            try:
+                __get_cfg()
+                bundle.Bundle().deploy_volumes()
+                __clean_cfg()
+            except Exception as msg:
+                LOGGER.error("Install volumes failed: %s", msg.message)
+                return 1
 
     # Command mdt reset
     # -------------------------
     if args.cmd == 'reset':
         if args.cmd_reset == 'products':
-            # Reset all products
-            mdtcli.call_mdt_cli('reset', 'products', unknown_args)
+            try:
+                # Reset all products
+                mdtcli.call_mdt_cli('reset', 'products', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Reset products failed: %s", msg.message)
+                return 1
 
         if args.cmd_reset == 'kube-cluster':
             try:
+                __get_cfg()
                 bundle.Bundle().reset_kubecluster()
+                __clean_cfg()
             except Exception as msg:
-                logger.error("Reset kube failed: %s" % msg.message)
+                __clean_cfg()
+                LOGGER.error("Reset Kube cluster failed: %s", msg.message)
                 return 1
             # Update mdt_api_products with Docker and Helm parameters after
             # Kube cluster reset
             # TODO: is it useful ?
 
+        if args.cmd_reset == 'volumes':
+            try:
+                __get_cfg()
+                bundle.Bundle().reset_volumes()
+                __clean_cfg()
+            except Exception as msg:
+                LOGGER.error("Reset volumes failed: %s", msg.message)
+                return 1
+
     # Command mdt load
     # -------------------------
     if args.cmd == 'load':
         if args.cmd_load == 'cfg':
-            # load config bundle files:
-            mdtcli.call_mdt_cli('load', 'cfg', unknown_args)
+            try:
+                # load config bundle files:
+                mdtcli.call_mdt_cli('load', 'cfg', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Loading MDT bundle failed: %s", msg.message)
+                return 1
 
         if args.cmd_load == 'chart':
             try:
-                # load helm chart tgz / load chart tgz:
-                if args.chart_tgz:
-                    # load_to_helm_repo(args.chart_tgz,args.chart_dir)
-                    tgz_dir = "none"
-                    helm.load_to_helm_repo(args.chart_tgz, tgz_dir)
-                elif args.chart_dir:
-                    tgz = "none"
-                    helm.load_to_helm_repo(tgz, args.chart_dir)
-                else:
-                    raise errors.LoadError(
-                        "Did you specify -p <mdt_package> option or -d <directory_containing_mdt_packages> option ?")
-
-            except Exception as e:
-                logger.error("Loading MDT package failed: %s" % e.message)
+                # load charts :
+                mdtcli.call_mdt_cli('load', 'chart', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Loading chart failed: %s", msg.message)
                 return 1
 
         if args.cmd_load == 'container':
@@ -650,7 +731,7 @@ def main():
 # regitry will be used
 
             except Exception as msg:
-                logger.error("Loading Containers failed: %s" % msg.message)
+                LOGGER.error("Loading Containers failed: %s", msg.message)
                 return 1
 
         if args.cmd_load == 'rpm':
@@ -658,7 +739,7 @@ def main():
                 load_yum_repo(args.rpm_tgz)
 
             except Exception as msg:
-                logger.error("Loading Rpm failed: %s" % msg.message)
+                LOGGER.error("Loading Rpm failed: %s", msg.message)
                 return 1
 
         if args.cmd_load == 'deb':
@@ -666,24 +747,116 @@ def main():
                 load_deb_repo(args.deb_tgz)
 
             except Exception as msg:
-                logger.error("Loading deb failed: %s" % msg.message)
+                LOGGER.error("Loading deb failed: %s", msg.message)
                 return 1
 
     # Command mdt-cli get
     # ----------------------
     if args.cmd == 'get':
         if args.cmd_get == 'label':
-            # get label
-            mdtcli.call_mdt_cli('get', 'label', unknown_args)
+            try:
+                # get label
+                mdtcli.call_mdt_cli('get', 'label', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Retreive label failed: %s", msg.message)
+                return 1
 
         if args.cmd_get == 'cfg':
-            # get config bundle files:
-            mdtcli.call_mdt_cli('get', 'cfg', unknown_args)
+            try:
+                # get config bundle files:
+                mdtcli.call_mdt_cli('get', 'cfg', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Retreive bundle failed: %s", msg.message)
+                return 1
 
-    if len(unknown_args) > 0:
-        logger.error("Unknown arguments : {}".format(unknown_args))
+        if args.cmd_get == 'chart':
+            try:
+                # get chart list:
+                mdtcli.call_mdt_cli('get', 'chart', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Retreive chart failed: %s", msg.message)
+                return 1
+
+        if args.cmd_get == 'context':
+            try:
+                # get chart list:
+                mdtcli.call_mdt_cli('get', 'context', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Retreive context failed: %s", msg.message)
+                return 1
+
+    # Command mdt set
+    # -------------------------
+    if args.cmd == 'set':
+        if args.cmd_set == 'node':
+            try:
+                bundle.Bundle().set_node(args.set_node_value, args.set_node_value_type)
+            except Exception as msg:
+                LOGGER.error("Set node failed: %s", msg.message)
+                return 1
+
+    # Command mdt unset
+    # -------------------------
+    if args.cmd == 'unset':
+        if args.cmd_unset == 'node':
+            try:
+                bundle.Bundle().unset_node(args.unset_node_value)
+            except Exception as msg:
+                LOGGER.error("Unset node failed: %s", msg.message)
+                return 1
+
+    # Command mdt audit
+    # -------------------------
+    if args.cmd == 'audit':
+        if args.cmd_audit == 'kube-cluster':
+            try:
+                __get_cfg()
+                bundle.Bundle().audit_kubecluster(args.node)
+                __clean_cfg()
+            except Exception as msg:
+                LOGGER.error("Audit Kube-cluster failed: %s", msg.message)
+                return 1
+
+    # Command mdt add
+    # -------------------------
+    if args.cmd == 'add':
+        if args.cmd_add == 'profile':
+            try:
+                mdtcli.call_mdt_cli('add', 'profile', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Add profile failed: %s", msg.message)
+                return 1
+
+    # Command mdt delete
+    # -------------------------
+    if args.cmd == 'delete':
+        if args.cmd_delete == 'profile':
+            try:
+                mdtcli.call_mdt_cli('delete', 'profile', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Delete profile failed: %s", msg.message)
+                return 1
+        if args.cmd_delete == 'chart':
+            try:
+                mdtcli.call_mdt_cli('delete', 'chart', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Delete chart failed: %s", msg.message)
+                return 1
+
+    # Command mdt upgrade
+    # -------------------------
+    if args.cmd == 'upgrade':
+        if args.cmd_upgrade == 'products':
+            try:
+                mdtcli.call_mdt_cli('upgrade', 'products', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Upgrade products failed: %s", msg.message)
+                return 1
+
+    if unknown_args:
+        LOGGER.error("Unknown arguments : %s", unknown_args)
         exit(2)
-    # logger.info("\n")
+    # LOGGER.info("\n")
     return 0
 
 
