@@ -24,7 +24,7 @@ __metaclass__ = type
 import os
 import sys
 import logging
-
+import requests
 from collections import namedtuple
 
 from ansible.parsing.dataloader import DataLoader
@@ -38,6 +38,7 @@ from ansible.executor.task_queue_manager import TaskQueueManager
 from ansible.plugins.callback import CallbackBase
 from ansible.utils.display import Display
 from ansible import constants as C
+from ericsson.deploypattern.lib.ansible_callback import EventsCallback
 
 import ericsson.deploypattern.lib.errors as errors
 
@@ -46,7 +47,7 @@ from ericsson.deploypattern.lib.utils import load_yaml, save_yaml
 from ericsson.deploypattern.lib.inventory import build_inventory
 from ericsson.deploypattern.lib.inventory import save_yaml_inventory
 from ericsson.deploypattern.lib.inventory import get_saved_node_list
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 
 class AnsiblePlay(object):
@@ -60,7 +61,6 @@ class AnsiblePlay(object):
                  options=None,
                  output=False):
 
-
         # initialize needed objects
         self.loader = DataLoader()
         self.passwords = {}
@@ -81,16 +81,16 @@ class AnsiblePlay(object):
         if host_list is None:
             host_list = get_saved_node_list()
             if host_list is None:
-                logger.error("No inventory found")
+                LOGGER.error("No inventory found")
                 raise errors.AnsibleError("No inventory found")
 
         if isinstance(host_list, list):
             for elt in host_list:
                 if isinstance(elt, dict):
                     self.inventory = InventoryManager(loader=self.loader,
-                                               #variable_manager=self.variable_manager,
-                                               #host_list=None)
-                                               sources=None)
+                                                      # variable_manager=self.variable_manager,
+                                                      # host_list=None)
+                                                      sources=None)
                     build_inventory(self.inventory, host_list)
                     save_yaml_inventory(host_list)
                     break
@@ -98,16 +98,16 @@ class AnsiblePlay(object):
         # Case host_list is not None or list, then it is path ?
         if self.inventory is None:
             self.inventory = InventoryManager(loader=self.loader,
-                                       #variable_manager=self.variable_manager,
-                                               #host_list=host_list)
-                                               sources=host_list)
-        self.variable_manager = VariableManager(loader=self.loader, inventory=self.inventory)
-
+                                              # variable_manager=self.variable_manager,
+                                              # host_list=host_list)
+                                              sources=host_list)
+        self.variable_manager = VariableManager(
+            loader=self.loader, inventory=self.inventory)
 
         if extra_vars is not None:
             self.variable_manager.extra_vars = extra_vars
 
-        # if logger.getEffectiveLevel() != 10 or output:
+        # if LOGGER.getEffectiveLevel() != 10 or output:
         #     self.results_callback = OnFailedCB()
         # else:
         self.results_callback = "default"
@@ -137,7 +137,7 @@ class AnsiblePlay(object):
             )
             result = tqm.run(play)
         except Exception as e:
-#            logger.error('ansible play failed')
+            #            LOGGER.error('ansible play failed')
             raise
         finally:
             if tqm is not None:
@@ -171,13 +171,13 @@ class AnsibleRunner(object):
             if remote_user is None:
                 remote_user = Config().get('ansible', 'remote_user')
         except Exception as e:
-            logger.error("get ansible config failed")
+            LOGGER.error("get ansible config failed")
             raise
 
         # force no check TODO add it as option
         ssh_extra_args = '-o StrictHostKeyChecking=no'
 
-        #if remote_user != 'root':
+        # if remote_user != 'root':
         become = True
         become_method = 'sudo'
         become_user = 'root'
@@ -213,7 +213,7 @@ class AnsibleRunner(object):
         :param tag:
         :return:
         """
-        logger.debug("add Ansible tag")
+        LOGGER.debug("add Ansible tag")
         tags_list = getattr(self.options, 'tags')
         tags_list.append(tag)
         self.options = self.options._replace(tags=tags_list)
@@ -224,7 +224,7 @@ class AnsibleRunner(object):
         :param tag:
         :return:
         """
-        logger.debug("add Ansible sqkip_tag")
+        LOGGER.debug("add Ansible sqkip_tag")
         tags_list = getattr(self.options, 'skip_tags')
         tags_list.append(tag)
         self.options = self.options._replace(skip_tags=tags_list)
@@ -277,7 +277,9 @@ class AnsibleRunner(object):
         )
         return play.play(play_source=play_source)
 
-    def playbook(self, playbooks=None, host_list=None, extra_vars=None, vars=None):
+    def playbook(self, playbooks=None, host_list=None, extra_vars=None,
+                 vars=None, manage_callback=False,
+                 next_status="deploymentInProgress", nodes=[]):
         """
         Execute a playbook
         """
@@ -290,25 +292,27 @@ class AnsibleRunner(object):
             if vars != None:
                 play.variable_manager.options_vars = vars
 
+            pbex = PlaybookExecutor(playbooks=[construct_playbook(playbooks)],
+                                    inventory=play.inventory,
+                                    variable_manager=play.variable_manager,
+                                    loader=play.loader,
+                                    options=self.options,
+                                    passwords=play.passwords)
 
-            pbex=PlaybookExecutor(playbooks = [construct_playbook(playbooks)],
-                                  inventory = play.inventory,
-                                  variable_manager = play.variable_manager,
-                                  loader = play.loader,
-                                  options = self.options,
-                                  passwords = play.passwords)
-
-            pbex._tqm._stdout_callback = play.results_callback
+            if manage_callback:
+                pbex._tqm._stdout_callback = EventsCallback(next_status, nodes)
+            else:
+                pbex._tqm._stdout_callback = play.results_callback
 
             # Clear pattern cache for inventory to update "all" pattern
             pbex._inventory.clear_pattern_cache()
 
             results = pbex.run()
         except errors.FileNotFound as e:
-            logger.error('Playbook not found %s: ' % playbooks)
+            LOGGER.error('Playbook not found %s: ', playbooks)
             raise
         except Exception as e:
-            logger.error('ansible playbook run failed')
+            LOGGER.error('ansible playbook run failed')
             raise
         return results
 
@@ -330,13 +334,13 @@ class AnsibleRunner(object):
             _f = _ff + ext
             if os.path.exists(_f):
                 allvars = load_yaml(_f)
-                logger.debug(json.dumps(allvars, indent=4))
+                LOGGER.debug(json.dumps(allvars, indent=4))
                 for key, item in allvars.iteritems():
                     if key not in varsdict.keys():
-                       varsdict[key] = item
+                        varsdict[key] = item
                     # Don't overwrite current variable but save it in all.yaml
                     else:
-                       allvars[key] = varsdict[key]
+                        allvars[key] = varsdict[key]
                 save_yaml(_f, allvars, style='"')
                 break
 
@@ -345,7 +349,7 @@ class AnsibleRunner(object):
         Method file_task
         """
         try:
-            logger.info("file task  %s" % cmd)
+            LOGGER.info("file task  %s", cmd)
 
             result = self.playtask(
                 host_list=nodes,
@@ -366,7 +370,7 @@ class AnsibleRunner(object):
         Method remote_command
         """
         try:
-            logger.info("exec command=%s" % cmd)
+            LOGGER.info("exec command=%s", cmd)
             extra_vars = {'ignore_errors': ignore_errors}
             result = self.playtask(
                 host_list=nodes,
@@ -391,7 +395,7 @@ class AnsibleRunner(object):
             raise errors.FileNotFound('%s: ' % file)
 
         try:
-            logger.info("copy file=%s dest=%s" % (file, dest))
+            LOGGER.info("copy file=%s dest=%s", file, dest)
             result = self.playtask(
                 host_list=nodes,
                 task=task,
@@ -414,90 +418,6 @@ class AnsibleRunner(object):
         self.file_task(nodes, mk_cmd)
 
 
-class OnFailedCB(CallbackBase):
-    """
-    Class OnFailedCB
-    """
-
-    @classmethod
-    def _command_generic_msg(self, result):
-    #~ def _command_generic_msg(self, host, result, caption):
-        ''' output the result of a command run '''
-        buf = ''
-        #buf = "%s | %s | rc=%s >>\n" % (host, caption, result.get('rc', -1))
-        #buf += result.get('stdout', '')
-        #buf += result.get('stderr', '')
-        buf += result.get('msg', '')
-
-        return buf + "\n"
-
-    def v2_runner_on_ok(self, result, **kwargs):
-        pass
-
-    def v2_runner_on_failed(self, result, ignore_errors=False):
-        if 'exception' in result._result:
-            if self._display.verbosity < 3:
-                # extract just the actual error message from the exception text
-                error = result._result['exception'].strip().split('\n')[-1]
-                msg = "An exception occurred during task execution. To see the " \
-                      "full traceback, use -vvv. The error was: %s" % error
-            else:
-                msg = "An exception occurred during task execution. " \
-                      "The full traceback is:\n" + \
-                      result._result['exception']
-
-            self._display.display(msg, color='red')
-
-            # finally, remove the exception from the result
-            # so it's not shown every time
-            del result._result['exception']
-
-        if result._task.action in C.MODULE_NO_JSON:
-            self._display.display(
-                self._command_generic_msg(result._host.get_name(),
-                                          result._result, "FAILED"),
-                color='red')
-        else:
-            #self._display.display("%s | FAILED! => %s" % (
-            #result._host.get_name(), self._dump_results(result._result, indent=4)),
-            #                      color='red')
-            self._display.display("%s: %s" % (
-                result._host.get_name(),
-                result._result[u'msg']),
-                                  color='red')
-
-
-class OnOutput(OnFailedCB):
-    """
-    Class OnOutput
-    """
-
-    def v2_runner_on_ok(self, result):
-        self._clean_results(result._result, result._task.action)
-        if result._task.action in C.MODULE_NO_JSON:
-            self._display.display(
-                self._command_generic_msg(result._host.get_name(),
-                                          result._result, "SUCCESS"),
-                color=C.COLOR_OK)
-        else:
-            if 'changed' in result._result and result._result['changed']:
-                self._display.display("%s | SUCCESS => %s" % (
-                    result._host.get_name(),
-                    self._dump_results(result._result, indent=4)),
-                                      color=C.COLOR_CHANGED)
-            else:
-                # self._display.display("%s | SUCCESS => %s" % (
-                # result._host.get_name(),
-                # self._dump_results(result._result, indent=4)),
-                #                       color=C.COLOR_OK)
-                self._display.display("%s: %s" % (
-                    result._host.get_name(),
-                    result._result[u'msg']),
-                                      color=C.COLOR_OK)
-
-            self._handle_warnings(result._result)
-
-
 def run_playbook(playbook_name):
     """
     Launch playbook on local host
@@ -506,7 +426,7 @@ def run_playbook(playbook_name):
     # check if localhost and add var :
     # ansible_python_interpreter: "/usr/bin/python"
     #~ playbook = construct_playbook(playbook_name)
-    extra_vars=get_config_vars_dict()
+    extra_vars = get_config_vars_dict()
     result = AnsibleRunner(). \
         playbook(host_list=[],
                  playbooks=playbook_name,
@@ -526,7 +446,7 @@ def get_ansible_path():
         pb_path = os.path.join(os.path.dirname(sys.argv[0]), 'ansible')
 
     if not os.path.exists(pb_path):
-        logger.error("Ansible path Not Found : %s " % pb_path)
+        LOGGER.error("Ansible path Not Found : %s ", pb_path)
         raise errors.FileNotFound('%s ' % pb_path)
 
     return str(pb_path)
@@ -552,14 +472,3 @@ def construct_playbook(name):
             raise errors.FileNotFound('%s: ' % playbook)
 
     return playbook
-
-
-#~ if __name__ == '__main__':
-    #~ _vars = {'path': '/'}
-    #~ ar = AnsibleRunner(remote_user="root", private_key_file="~/.ssh/id_rsa.es")
-    #~ res = ar.playroles(host_list=['10.86.71.228', '10.86.71.228'],
-                       #~ roles=["role"],
-                       #~ vars=_vars)
-    #~ res = ar.playtask(host_list=['10.86.71.228'],
-                      #~ task="shell",
-                      #~ args="ls /")
