@@ -30,7 +30,7 @@ import logging
 
 import ericsson.deploypattern.lib.errors as errors
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 DEFAULT = {
     'global': {
@@ -44,17 +44,10 @@ DEFAULT = {
         'path': ''
     },
 
-    'pattern': {
-        'path': ''
-    },
-
-    'bundle': {
-        'path': ''
-    },
-
     'docker': {
         'registry_address': '',
         'registry_port': '5001',
+        'registry_sub': '',
         'registry_version': '2.6.2dck1',
         'registry_nfs_ip': '',
         'registry_nfs_path': '/var/lib/docker/registry',
@@ -68,12 +61,16 @@ DEFAULT = {
     },
 
     'helm_repo': {
+        'address': 'http://chartmuseum:8080',
         'path': '/var/www/ericsson',
         'name': 'helm_repo'
     },
 
     'compose': {
         'path': ''
+    },
+    'bundle': {
+        'path': ''
     }
 }
 
@@ -128,8 +125,16 @@ class Config(object):
         raise AttributeError(attr)
 
     def get_file_conf(self):
+        """
+
+        :param:
+        :return:
+        """
         return self._conf
 
+    def get_default_conf(self):
+        return DEFAULT
+
     def set_registry(self, registry):
         """
         Set insecure Docker registry yo use instead to the default Docker
@@ -137,18 +142,35 @@ class Config(object):
         :param registry: (IP_ADDRESS | HOSTNAME)[:PORT]
         :return:
         """
-        if ':' in registry:
-            addr, port = registry.split(':', 1)
+        if registry == "local":
+            addr = self.get('global', 'mgnt_ip_addr')
+            port = DEFAULT.get('docker').get('registry_port')
+            subrepo = ""
+        elif ':' in registry:
+            if '/' in registry:
+                full_addr, subrepo = registry.split('/', 1)
+                addr, port = full_addr.split(':', 1)
+            else:
+                addr, port = registry.split(':', 1)
+                subrepo = ""
         else:
-            addr = registry
+            if '/' in registry:
+                addr, subrepo = registry.split('/', 1)
+            else:
+                addr = registry
+                subrepo = ""
             port = "80"
-
         self.set('docker', 'registry_address', addr)
         self.set('docker', 'registry_port', port)
+        self.set('docker', 'registry_sub', subrepo)
 
     @staticmethod
     def __retrive_pkg_path():
-        # get the path of deploypattern package
+        """
+        get the path of deploypattern package
+        :param:
+        :return:
+        """
         realpath = os.path.realpath(sys.argv[0])
         bindir = os.path.dirname(realpath)
         pkgdir = os.path.dirname(bindir)
@@ -156,6 +178,11 @@ class Config(object):
 
 
 def get_config_vars_dict():
+    """
+    get the config var as dict
+    :param:
+    :return:
+    """
     dict_vars = {
         'mgnt_ip_addr': Config().get('global', 'mgnt_ip_addr'),
         'path': Config().get('global', 'path'),
@@ -167,6 +194,7 @@ def get_config_vars_dict():
 
         'bundle_path': Config().get('bundle', 'path'),
 
+        'helm_repo_address': Config().get('helm_repo', 'address'),
         'helm_repo_path': Config().get('helm_repo', 'path'),
         'helm_repo_name': Config().get('helm_repo', 'name'),
 
@@ -175,8 +203,7 @@ def get_config_vars_dict():
         'registry_nfs_ip': Config().get('docker', 'registry_nfs_ip'),
         'registry_nfs_path': Config().get('docker', 'registry_nfs_path'),
         'registry_port': Config().get('docker', 'registry_port'),
-        'docker_registry': Config().get('docker', 'registry_address') + ':' +
-                              Config().get('docker', 'registry_port'),
+        'docker_registry': '',
 
         'ansible_path': Config().get('ansible', 'path'),
         'role_path': os.path.join(Config().get('ansible', 'path'), 'roles'),
@@ -184,47 +211,134 @@ def get_config_vars_dict():
         'ansible_python_interpreter': "/usr/bin/python"
 
     }
+
+    if Config().get('docker', 'registry_sub') == '':
+        dict_vars['docker_registry'] = \
+            Config().get('docker', 'registry_address') + ':' \
+                            + Config().get('docker', 'registry_port')
+    else:
+        dict_vars['docker_registry'] = \
+            Config().get('docker', 'registry_address') + ':' \
+                            + Config().get('docker', 'registry_port') + '/' \
+                            + Config().get('docker', 'registry_sub')
+
     return dict_vars
 
 
 def get_ssh_key_file():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('ansible', 'ssh_key')
 
 
 def get_remote_user():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('ansible', 'remote_user')
 
 
 def get_helm_charts_server():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('helm_repo', 'path')
 
 
 def get_helm_charts_reponame():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('helm_repo', 'name')
 
 
 def get_mdt_node():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('global', 'mgnt_ip_addr')
 
 def get_docker_node():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('docker', 'registry_address')
 
 
 def get_http_port():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('global', 'http_port')
 
 
 def get_tiller_server():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('tiller', 'server')
 
 
 def get_tiller_port():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('tiller', 'port')
 
 
 def get_compose_path():
+    """
+
+    :param:
+    :return:
+    """
     return Config().get('compose', 'path')
 
 
 def get_docker_registry_url():
-    return Config().get('docker', 'registry_address') + ':' + Config().get('docker', 'registry_port')
+    """
+
+    :param:
+    :return:
+    """
+    if Config().get('docker', 'registry_sub') == '':
+        return Config().get('docker', 'registry_address') + ':' + \
+               Config().get('docker', 'registry_port')
+    return Config().get('docker', 'registry_address') + ':' + \
+           Config().get('docker', 'registry_port') + '/' + \
+           Config().get('docker', 'registry_sub')
+
+def get_repo_path():
+    """
+
+    :param:
+    :return:
+    """
+    return Config().get('repo', 'path')
+
+def get_repo_name():
+    """
+
+    :param:
+    :return:
+    """
+    return Config().get('repo', 'name')
