@@ -27,7 +27,7 @@ import tarfile
 import json
 import requests
 import subprocess
-
+import re
 import ericsson.deploypattern.lib.errors as errors
 
 from docker.errors import ImageNotFound, APIError
@@ -35,7 +35,7 @@ from docker.errors import ImageNotFound, APIError
 from docker import DockerClient, APIClient
 from ericsson.deploypattern.lib.config import Config
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 
 class DockerLib(object):
@@ -44,34 +44,33 @@ class DockerLib(object):
     def __init__(self, host=None, port=None):
         """ Connect to the docker daemon """
 
-
         # To access remote docker daemon via TCP -> more difficult
         # Our Docker installation via Ansible doesn't configure TCP option
-        #if Config().get('docker', 'registry_address') == \
+        # if Config().get('docker', 'registry_address') == \
         #        Config().get('global', 'mgnt_ip_addr'):
         #    base_url = 'unix://var/run/docker.sock'
-        #else:
+        # else:
         #    base_url = "http://%s:%s" % \
         #               (Config().get('docker', 'registry_address'), \
         #                Config().get('docker', 'registry_port'))
 
         # Access to server daemon docker local
         base_url = 'unix://var/run/docker.sock'
-        logger.debug("docker base_url: %s " % base_url)
+        LOGGER.debug("docker base_url: %s ", base_url)
 
         try:
             # TODO: use only DockerClient and not low level API
             self.docker = DockerClient(base_url=base_url, timeout=240)
             self.docker_api = APIClient(base_url=base_url, timeout=240)
-        except Exception as e:
-            logger.error('No docker daemon running ? ')
+        except Exception as msg:
+            LOGGER.error('No docker daemon running ? ')
             raise
 
         try:
-            self.registry_address  = Config().get('docker', 'registry_address')
+            self.registry_address = Config().get('docker', 'registry_address')
             self.registry_port = Config().get('docker', 'registry_port')
-        except  Exception as e:
-            logger.error('Config value not found')
+        except Exception as msg:
+            LOGGER.error('Config value not found')
             raise
 
         self.registry = self.registry_address + ":" + self.registry_port
@@ -85,8 +84,16 @@ class DockerLib(object):
         :return:
         """
         img = self.docker.images.get(name + ':' + tag)
+        # make sure the clean will not delete more tags than necessary
+        regex = re.compile(r".*:%s|.*:latest" % re.escape(tag))
         for __tag in img.tags:
-            self.docker.images.remove(__tag, force=True)
+            try:
+                match = regex.match(__tag)
+                if match.group(0) == __tag:
+                    self.docker.images.remove(__tag, force=True)
+            except AttributeError:
+                # ignore error when regex is not ok
+                pass
 
     def load_tgz_image(self, image, force=False):
         """
@@ -100,14 +107,16 @@ class DockerLib(object):
         :return: list of loaded images [ "name:tag" ..]
         """
         try:
-            logger.info("  -> loading image: %s " % image)
-            if os.path.splitext(image)[-1] not in ['.gz','.tar','.tgz']:
-                logger.error('Unknown extension {}... exiting'.format(os.path.splitext(image)[-1]))
+            LOGGER.info("  -> loading image: %s ", image)
+            if os.path.splitext(image)[-1] not in ['.gz', '.tar', '.tgz']:
+                LOGGER.error('Unknown extension %s... exiting', os.path.splitext(image)[-1])
                 return []
 
             # Search all tags (image:version) in manifest file
-            manifest = json.load(tarfile.open(image).extractfile("manifest.json"))
-            tags = [ manifest[x]["RepoTags"][0] for x in range(len(manifest)) ]
+            tar = tarfile.open(image)
+            manifest = json.load(tar.extractfile("manifest.json"))
+            tar.close()
+            tags = [manifest[x]["RepoTags"][0] for x in range(len(manifest))]
             # Force load image(s) in local
             if force:
                 subprocess.call(['sudo', 'docker', 'load', '-i', '{}'.format(image)])
@@ -131,17 +140,15 @@ class DockerLib(object):
                 subprocess.call(['sudo', 'docker', 'load', '-i', '{}'.format(image)])
                 return tags
             # Case
-            else:
-                logger.info("  -> Not loading image: %s, because already load " % image)
-                return []
+            LOGGER.info("  -> Not loading image: %s, because already load ", image)
+            return []
         # Case Incorrect registry URL
-        except requests.exceptions.ConnectionError as e:
-              raise errors.LoadError (" ERROR: Check if Docker registry is up" )
-        except Exception as e:
-            logger.error("loading image %s failed " % image)
+        except requests.exceptions.ConnectionError as msg:
+            raise errors.LoadError("ERROR: Check if Docker registry is up")
+        except Exception as msg:
+            LOGGER.error("loading image %s failed ", image)
             raise
 
-
     def push_image(self, name, tag):
         """
         Push an image (name:tag) on the current Docker registry
@@ -153,40 +160,36 @@ class DockerLib(object):
         """
         repository = os.path.join(self.registry, name)
         try:
-            logger.debug("get image %s:%s" % (name, tag))
+            LOGGER.debug("get image %s:%s", name, tag)
             img = self.docker.images.get(name + ':' + tag)
             # Tag to push
-            logger.debug(" - tag image: %s:%s and latest" % (repository, tag))
+            LOGGER.debug(" - tag image: %s:%s and latest", repository, tag)
             img.tag(repository=repository, tag=tag)
             img.tag(repository=repository, tag="latest")
             # Push
             cr = self.docker.images.push(repository,
-                                    tag=tag,
-                                    insecure_registry=True)
+                                         tag=tag,
+                                         insecure_registry=True)
             if not 'error' in cr:
-                logger.info("  -> pushing image: %s:%s %s \n" % (repository,
-                                                           tag,
-                                                           img.short_id))
-                self.docker.images.push(repository,
-                                    tag="latest",
-                                    insecure_registry=True)
+                LOGGER.info("  -> pushing image: %s:%s %s \n", repository, tag, img.short_id)
+                self.docker.images.push(repository, tag="latest", insecure_registry=True)
             else:
                 # Clean local images
-                self.clean_image(name,tag)
+                self.clean_image(name, tag)
                 raise errors.LoadError("ERROR pushing image %s:%s %s. Check if the Docker registry is up" \
-                            % (repository, tag, img.short_id))
+                                       % (repository, tag, img.short_id))
 
         except ImageNotFound:
-            logger.error('image -%s:%s- not found' % (name, tag))
+            LOGGER.error('image -%s:%s- not found', name, tag)
             raise
-        except Exception as e:
-            logger.error("pushing image %s:%s failed " % (name, tag))
+        except Exception as msg:
+            LOGGER.error("pushing image %s:%s failed ", name, tag)
             raise
 
         try:
-            self.clean_image(name,tag)
-        except Exception as e:
-            logger.error("removing tmp image %s:%s failed " % (name, tag))
+            self.clean_image(name, tag)
+        except Exception as msg:
+            LOGGER.error("removing tmp image %s:%s failed ", name, tag)
             pass
 
     def delete_image(self, name, version):
@@ -206,8 +209,8 @@ class DockerLib(object):
         """
         try:
             img = self.docker.images.get(image)
-        except Exception as e:
-            logger.error("getting image %s failed " % image)
+        except Exception as msg:
+            LOGGER.error("getting image %s failed ", image)
             raise
         return img.id
 
@@ -225,27 +228,24 @@ class DockerLib(object):
         :param name:
         :return:
         """
-        list = self.docker.containers.list(all=True)
-        for container in list:
-            logger.debug("Container: %s - status: %s" %
-                         (container.name, container.status))
+        cont_list = self.docker.containers.list(all=True)
+        for container in cont_list:
+            LOGGER.debug("Container: %s - status: %s", container.name, container.status)
             if container.name == name:
                 try:
                     # stop it first if running
                     if container.status == r'running':
-                        logger.debug("stopping: %s " % container.name)
+                        LOGGER.debug("stopping: %s ", container.name)
                         container.stop()
 
                     container = self.docker.containers.get(container.id)
 
                     # remove it finally
-                    logger.debug("removing: %s - %s" %
-                                 (container.name, container.status))
+                    LOGGER.debug("removing: %s - %s", container.name, container.status)
                     container.remove(force=True)
 
-                except Exception as e:
-                    logger.debug("Error on removing container: %s ",
-                                 container.name)
+                except Exception as msg:
+                    LOGGER.debug("Error on removing container: %s ", container.name)
                     # do not raise error: bypass error in devmapper loop
                     # docker filesystem backend
                     pass
@@ -254,11 +254,11 @@ class DockerLib(object):
     @staticmethod
     def get_name_tag_from_archive(image):
         """ Get name and tag from a tar.gz image file """
-        logger.debug("image archive: %s " % image)
+        LOGGER.debug("image archive: %s ", image)
 
         version_regexp = [r"(v\d+\.\d+\.\d+-\d+\D{3}\d+)",
                           r"(\d+\.\d+\.\d+-\d+\D{3}\d+)",
-						  r"(\d+\.\d+\.\d+\D{3}\d+)",
+                          r"(\d+\.\d+\.\d+\D{3}\d+)",
                           r"(v\d+\.\d+\.\d+-beta\.\d+)",
                           r"(v\d+\.\d+\.\d+-amd64)",
                           r"(\d+\.\d+\.\d+-kubeadm)",
@@ -274,21 +274,21 @@ class DockerLib(object):
         __found = False
         for __re in version_regexp:
             if re.search(__re, os.path.basename(image)):
-                m = re.split(__re,
-                             os.path.basename(image))
-                logger.debug("image found: %s:%s " % (m[1], m[0]))
+                img = re.split(__re,
+                               os.path.basename(image))
+                LOGGER.debug("image found: %s:%s ", img[1], img[0])
                 __found = True
                 break
 
         if __found:
-            img_tag  = m[1]
-            img_name = m[0]
+            img_tag = img[1]
+            img_name = img[0]
         else:
             raise errors.ImageNameError("could not get name:tag for image: %s"
                                         % image)
 
         # remove '-' character between name and version
-        if m[0][-1:] == '-':
-            img_name = m[0][:-1]
+        if img[0][-1:] == '-':
+            img_name = img[0][:-1]
 
         return img_name, img_tag
