@@ -21,22 +21,21 @@ from __future__ import (absolute_import, division, print_function)
 
 import logging
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
-__plugins = []
+__PLUGINS = []
 
 
 def register_plugin(name, cls):
     """ Register plugins """
-    logger.debug("register : %s - %s" % (name, cls.__name__))
-    __plugins.append((name, cls))
+    LOGGER.debug("register : %s - %s", name, cls.__name__)
+    __PLUGINS.append((name, cls))
 
 
 def load_plugin(name):
     """ Load plugins """
-    for __name, __cls in __plugins:
+    for __name, __cls in __PLUGINS:
         if __name == name:
-            logger.debug("load : %s - %s" % (__name, __cls.__name__))
+            LOGGER.debug("load : %s - %s", __name, __cls.__name__)
             return __cls
     raise NotImplementedError("No plugin name %s" % name)
-
