@@ -34,12 +34,16 @@ import ericsson.deploypattern.lib.errors as errors
 
 from ericsson.deploypattern.lib.config import Config
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
-CREATEREPO='/usr/bin/createrepo'
+CREATEREPO = '/usr/bin/createrepo'
 
 
 def __get_repo_path():
+    """
+    Get path of local yum repository
+    :return:
+    """
     repo = Config().get('repo', 'path') + '/' + \
            Config().get('repo', 'name')
     return repo
@@ -49,15 +53,15 @@ def create_yum_repo():
     """ Create a local yum repository """
     try:
         repo_path = __get_repo_path()
-        logger.info(":: creating YUM repository in %s" % repo_path)
+        LOGGER.info(":: creating YUM repository in %s", repo_path)
 
         if not os.path.exists(repo_path):
             os.makedirs(repo_path)
 
         subprocess.call([CREATEREPO, repo_path],
                         stdout=DEVNULL, stderr=subprocess.STDOUT)
-    except Exception as e:
-        raise errors.InitError(e)
+    except Exception as msg:
+        raise errors.InitError(msg)
 
 
 def load_yum_repo(tgz):
@@ -68,37 +72,34 @@ def load_yum_repo(tgz):
         if not os.path.exists(repo_path):
             raise errors.LoadError("Did you call init before ?")
 
-        logger.info(":: updating YUM repository %s" % repo_path)
+        LOGGER.info(":: updating YUM repository %s", repo_path)
 
         if tarfile.is_tarfile(tgz) is not True:
             raise errors.LoadError("%s is not a tar file" % tgz)
 
         tar = tarfile.open(tgz)
-        for file in tar.getmembers():
-            if file.isfile():
-                logger.debug(" - > tar members %s" % file.name)
-                if file.name.lower().endswith('.rpm'):
+        for rpm_file in tar.getmembers():
+            if rpm_file.isfile():
+                LOGGER.debug(" - > tar members %s", rpm_file.name)
+                if rpm_file.name.lower().endswith('.rpm'):
                     # check if there is not ../ in file path
-                    if re.match(r'\.\./', file.name):
+                    if re.match(r'\.\./', rpm_file.name):
                         raise errors.LoadError(
                             "suspicious filename with /../ in path")
 
                     # check if filename not begin with /
-                    if re.match('^/', file.name):
+                    if re.match('^/', rpm_file.name):
                         raise errors.LoadError(
                             "suspicious filename start with /")
 
-                    logger.info(" - > extracting RPM %s" % file.name)
-                    tar.extract(file, path=repo_path)
+                    LOGGER.info(" - > extracting RPM %s", rpm_file.name)
+                    tar.extract(rpm_file, path=repo_path)
                 else:
                     raise errors.LoadError("is %s contains rpms ?" % tgz)
         tar.close()
 
         subprocess.call([CREATEREPO, "--update", repo_path],
                         stdout=DEVNULL, stderr=subprocess.STDOUT)
-    except Exception as e:
-        raise errors.LoadError(e)
+    except Exception as msg:
+        raise errors.LoadError(msg)
         #raise
-
-
-
