@@ -1,10 +1,11 @@
 from __future__ import unicode_literals
 
 import json
+import os
 from base64 import b64encode
 
 from hvac import aws_utils, exceptions, adapters, utils, api
-from hvac.constants.client import DEPRECATED_PROPERTIES
+from hvac.constants.client import DEPRECATED_PROPERTIES, DEFAULT_URL
 
 try:
     import hcl
@@ -16,7 +17,7 @@ except ImportError:
 class Client(object):
     """The hvac Client class for HashiCorp's Vault."""
 
-    def __init__(self, url='http://localhost:8200', token=None,
+    def __init__(self, url=None, token=None,
                  cert=None, verify=True, timeout=30, proxies=None,
                  allow_redirects=True, session=None, adapter=None, namespace=None):
         """Creates a new hvac client instance.
@@ -50,6 +51,8 @@ class Client(object):
         if adapter is not None:
             self._adapter = adapter
         else:
+            token = token if token is not None else utils.get_token_from_env()
+            url = url if url else os.getenv('VAULT_ADDR', DEFAULT_URL)
             self._adapter = adapters.Request(
                 base_uri=url,
                 token=token,
@@ -179,7 +182,7 @@ class Client(object):
         :return: The JSON response of the request.
         :rtype: dict
         """
-        return self.read_seal_status()
+        return self.sys.read_seal_status()
 
     def read(self, path, wrap_ttl=None):
         """GET /<path>
@@ -273,7 +276,7 @@ class Client(object):
                      no_parent=False, lease=None, display_name=None,
                      num_uses=None, no_default_policy=False,
                      ttl=None, orphan=False, wrap_ttl=None, renewable=None,
-                     explicit_max_ttl=None, period=None):
+                     explicit_max_ttl=None, period=None, token_type=None):
         """POST /auth/token/create
 
         POST /auth/token/create/<role>
@@ -310,6 +313,8 @@ class Client(object):
         :type explicit_max_ttl:
         :param period:
         :type period:
+        :param token_type:
+        :type token_type:
         :return:
         :rtype:
         """
@@ -335,6 +340,8 @@ class Client(object):
 
         if period:
             params['period'] = period
+        if token_type:
+            params['type'] = token_type
 
         if orphan:
             return self._adapter.post('/v1/auth/token/create-orphan', json=params, wrap_ttl=wrap_ttl).json()
@@ -1369,7 +1376,7 @@ class Client(object):
         return self._adapter.post(url, json=params)
 
     def delete_role_secret_id_accessor(self, role_name, secret_id_accessor, mount_point='approle'):
-        """DELETE /auth/<mount_point>/role/<role name>/secret-id/<secret_id_accessor>
+        """POST /auth/<mount_point>/role/<role name>/secret-id-accessor/destroy
 
         :param role_name:
         :type role_name:
@@ -1380,8 +1387,11 @@ class Client(object):
         :return:
         :rtype:
         """
-        url = '/v1/auth/{0}/role/{1}/secret-id-accessor/{2}'.format(mount_point, role_name, secret_id_accessor)
-        return self._adapter.delete(url)
+        url = '/v1/auth/{0}/role/{1}/secret-id-accessor/destroy'.format(mount_point, role_name)
+        params = {
+            'secret_id_accessor': secret_id_accessor
+        }
+        return self._adapter.post(url, json=params)
 
     def create_role_custom_secret_id(self, role_name, secret_id, meta=None, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/custom-secret-id
